#[non_exhaustive]pub enum TransportSecurity {
TlsOnly,
AllowInsecureHttp,
}Expand description
Transport security configuration
Controls whether the client enforces TLS or allows insecure HTTP.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
TlsOnly
Require TLS for all connections (HTTPS only) - default and recommended
AllowInsecureHttp
Allow insecure HTTP connections (for testing with mock servers only)
WARNING: This should only be used for local testing with mock servers. Never use in production as it exposes traffic to interception.