RetryLayer

Struct RetryLayer 

pub struct RetryLayer { /* private fields */ }
Tower layer that implements retry with exponential backoff and jitter

This layer operates on services that return HttpError and makes retry decisions based on error type and HTTP status codes.

Implementations

Source

impl RetryLayer

pub fn new(config: RetryConfig) -> Self

Create a new RetryLayer with the specified configuration

pub fn with_total_timeout( config: RetryConfig, total_timeout: Option<Duration>, ) -> Self

Create a new RetryLayer with total timeout (deadline across all retries)