pub type ResponseBody = BoxBody<Bytes, Box<dyn Error + Send + Sync>>;Expand description
Type alias for the boxed response body that supports decompression.
This type can hold either a raw body or a decompressed body (gzip/br/deflate). The body is type-erased to allow the decompression layer to work transparently.
Aliased Type
pub struct ResponseBody { /* private fields */ }